summaryrefslogtreecommitdiff
path: root/misc/xtide/patches/patch-ab
blob: 44dac314406be8c56696d531c5de762cd335f7ef (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
$NetBSD: patch-ab,v 1.2 2003/07/22 21:14:47 jmmv Exp $

--- TideContext.cc.orig	Fri Mar 23 21:52:40 2001
+++ TideContext.cc	Thu May 31 13:48:53 2001
@@ -42,12 +42,12 @@
   colors = in_colors;
   settings = in_settings;
 
   // Get HFILE_PATH from environment or /etc/xtide.conf and create
   // persistent HarmonicsPath
   Dstr hfile_path (getenv ("HFILE_PATH"));
   if (hfile_path.isNull()) {
     FILE *configfile;
-    if ((configfile = fopen ("/etc/xtide.conf", "r"))) {
+    if ((configfile = fopen (PKG_SYSCONFDIR "/xtide.conf", "r"))) {
       hfile_path.getline (configfile);
       fclose (configfile);
     }
@@ -42,12 +42,12 @@
   settings = in_settings;
 
-  // Get HFILE_PATH from environment or /etc/xtide.conf and create
+  // Get HFILE_PATH from environment or ${PKG_SYSCONFDIR}/xtide.conf and create
   // persistent HarmonicsPath
   Dstr hfile_path (getenv ("HFILE_PATH"));